]> ruderich.org/simon Gitweb - config/dotfiles.git/blobdiff - setup.sh
.gitignore: Use absolute paths.
[config/dotfiles.git] / setup.sh
index 25f46843905f0823c507c4500f3dd9364eb5d296..cce1d19a0d0dfd35b764db8bea97de421c899678 100755 (executable)
--- a/setup.sh
+++ b/setup.sh
@@ -14,12 +14,14 @@ fi
 
 if installed X; then
     # Prevent code duplication. Term* rules are for all terminals; XTerm rules
# are for XTerm and UXTerm. At the moment XTerm and UXTerm are supported.
     generate perl Xdefaults -ne \
         'if (/^Term/) {
              s/^Term//;
              print "XTerm", $_;
              print "UXTerm", $_;
+             print "Rxvt", $_;
          } elsif (/^XTerm/) {
              print $_;
              s/^XTerm//;
@@ -32,9 +34,14 @@ if installed X; then
     sed 's/^#/!/' Xdefaults > Xdefaults.tmp
     mv Xdefaults.tmp Xdefaults
 
-    if [ `os` != darwin ]; then
+    if [ x`os` != xdarwin ]; then
         link xinitrc ~/.xinitrc
     fi
     link xmodmaprc ~/.xmodmaprc
     link Xdefaults ~/.Xdefaults
+    link XCompose ~/.XCompose
+fi
+
+if installed xpdf; then
+    link xpdfrc ~/.xpdfrc
 fi
@@ -14,12 +14,14 @@ fi
 if installed X; then
     # Prevent code duplication. Term* rules are for all terminals; XTerm rules
-    # are for XTerm and UXTerm. At the moment XTerm and UXTerm are supported.
+    # are for XTerm and UXTerm. At the moment XTerm, UXTerm and Rxvt are
+    # supported.
     generate perl Xdefaults -ne \
         'if (/^Term/) {